@@ -88,7 +88,10 @@ def sql(key):
         'KAIAlertEnableId': {'sql':"SELECT id From KAIAlert Where status = 1 ;",'database': 'AnyRobot'},
         'KAIAlertDisableId': {'sql':"SELECT id From KAIAlert Where status = 0 ;",'database': 'AnyRobot'},
         'ScheduleTaskEnableId': {'sql':"SELECT id From ScheduleTask Where status = 1 ;",'database': 'AnyRobot'},
-        'ScheduleTaskDisableId': {'sql':"SELECT id From ScheduleTask Where status = 0 ;",'database': 'AnyRobot'}
+        'ScheduleTaskDisableId': {'sql':"SELECT id From ScheduleTask Where status = 0 ;",'database': 'AnyRobot'},
+        'ReprotId': {'sql': "SELECT reprot_id From report ;", 'database': 'AnyRobot'},
+        'ReprotName': {'sql': "SELECT `name` From report ;", 'database': 'AnyRobot'},
+        'ReprotType': {'sql': "SELECT `type` From report ;", 'database': 'AnyRobot'}
     }
 
     if switcher.get(key) is not None:
